@@ -18,12 +18,14 @@ has time => (
 
 # FIXME - User running script?
 
+with qw( Log::Message::Structured );
+with qw( Log::Message::Structured::Component::Date
+         Log::Message::Structured::Component::Hostname
+      );
 with 'Log::Message::Structured::Stringify::Sprintf' => {
     format_string => q{Script %s run on %s for %ss},
     attributes => [qw/ script_name hostname time /],
-}, 'Log::Message::Structured';
-with qw(Log::Message::Structured::Component::Date);
-with qw(Log::Message::Structured::Component::Hostname);
+};
 
 =head1 NAME
 
